@@ -29,12 +29,12 @@
 #include <tqpixmap.h>
 #include <tqtimer.h>
 #include <knotifyclient.h>
-#include <kaboutdata.h>
-#include <kcmdlineargs.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <tdeaboutdata.h>
+#include <tdecmdlineargs.h>
+#include <tdelocale.h>
+#include <tdeapplication.h>
 #include <kiconloader.h>
-#include <kglobalsettings.h>
+#include <tdeglobalsettings.h>
 
 #include <stdlib.h>
 #include <errno.h>
@@ -51,7 +51,7 @@ NotifierContainer::NotifierContainer() : TQWidget() {
 
 	// Determine bottom of desktop
 	TQPoint cursorPos = TQCursor::pos();
-	TQRect r = KGlobalSettings::desktopGeometry(cursorPos);
+	TQRect r = TDEGlobalSettings::desktopGeometry(cursorPos);
 	mTopOfStack = r.height();
 	mRightOfStack = r.width();
 }
@@ -65,10 +65,10 @@ void NotifierContainer::handleGTKMain() {
 
 void NotifierContainer::displayMessage(TQString title, TQString message, TQString icon, int x, int y) {
 	TQPixmap px;
-	KIconLoader* il = KGlobal::iconLoader();
-	px = il->loadIcon( icon, KIcon::NoGroup );
+	TDEIconLoader* il = TDEGlobal::iconLoader();
+	px = il->loadIcon( icon, TDEIcon::NoGroup );
 // 	if (px.isNull()) {
-// 		px = il->loadIcon( "gnome_apps", KIcon::NoGroup );
+// 		px = il->loadIcon( "gnome_apps", TDEIcon::NoGroup );
 // 	}
 
 	KPassivePopup *pop = new KPassivePopup( KPassivePopup::Boxed, this, "" );
@@ -80,7 +80,7 @@ void NotifierContainer::displayMessage(TQString title, TQString message, TQStrin
 		if (mPopupList.isEmpty()) {
 			// Determine bottom of desktop
 			TQPoint cursorPos = TQCursor::pos();
-			TQRect r = KGlobalSettings::desktopGeometry(cursorPos);
+			TQRect r = TDEGlobalSettings::desktopGeometry(cursorPos);
 			mTopOfStack = r.height();
 			mRightOfStack = r.width();
 		}
@@ -108,7 +108,7 @@ void NotifierContainer::popupClosed(KPassivePopup* popup) {
 	if (mPopupList.isEmpty()) {
 		// Determine bottom of desktop
 		TQPoint cursorPos = TQCursor::pos();
-		TQRect r = KGlobalSettings::desktopGeometry(cursorPos);
+		TQRect r = TDEGlobalSettings::desktopGeometry(cursorPos);
 		mTopOfStack = r.height();
 		mRightOfStack = r.width();
 	}
@@ -231,9 +231,10 @@ notify_daemon_notify_handler(NotifyDaemon *daemon,
 	}
 
 	// Send a notification request to KDE here...
-	TQString messageText = TQString(body);
+	TQString messageCaption = TQString::fromLocal8Bit(summary);
+	TQString messageText = TQString::fromLocal8Bit(body);
 
-	GTKNotifierContainer->displayMessage(TQString(summary), TQString(body), TQString(icon), x, y);
+	GTKNotifierContainer->displayMessage(messageCaption, messageText, TQString(icon), x, y);
 
 	return_id = 0;
 
@@ -344,14 +345,14 @@ main(int argc, char **argv)
 										"/org/freedesktop/Notifications",
 										G_OBJECT(daemon));
 
-	KAboutData aboutData("notification-daemon-tde", I18N_NOOP("TDE DBUS Notification Daemon"), version,
-		description, KAboutData::License_GPL,
+	TDEAboutData aboutData("notification-daemon-tde", I18N_NOOP("TDE DBUS Notification Daemon"), version,
+		description, TDEAboutData::License_GPL,
 		"(c) 2011, Timothy Pearson",
 		message, 0 /* TODO: Website */, "kb9vqf@pearsoncomputing.net");
 
-	KCmdLineArgs::init(argc, argv, &aboutData);
+	TDECmdLineArgs::init(argc, argv, &aboutData);
 
-	KApplication app;
+	TDEApplication app;
 	NotifierContainer nc;
 	app.setMainWidget(&nc);
 	GTKNotifierContainer = &nc;
